/*-----------------------------------------------------------------------*/
/*  (C) Copyright Institute for Astronomy ETHZ 8093 Zuerich Switzerland  */
/*-----------------------------------------------------------------------*/
/*  Programmname: unit1.cpp                                              */
/*                                                                       */
/*  Revision: V1.2     Date: 29.06.2017    Autor: Chr. Monstein          */
/*                                                                       */
/*  Purpose: Callisto installation tool                                  */
/*                                                                       */
/*  Compiler: BORLAND C++Builder 6                                       */
/*-----------------------------------------------------------------------*/

// Created by: Chr. Monstein 29.06.2017
// Updated by: Chr. Monstein 03.07.2017
// Updated by: Chr. Monstein 28.07.2017 multi CALLISTO on the same PC
// Updated by: Chr. Monstein 15.09.2017 added python-LC plotter, wwwpar.cfg scale 1->4
// Updated by: Chr. Monstein 25.09.2017 delete icon LCPYPLOT
// Updated by: Chr. Monstein 26.10.2017 add Python/Calibration
// Updated by: Chr. Monstein 10.12.2018 del installation ssfree.exe, delay in PERL-script
// Updated by: Chr. Monstein 30.10.2021 reduction to the relevant applications -LC, -analyses
//---------------------------------------------------------------------------

#include <vcl.h>
#pragma hdrstop

#include "Unit1.h"
#include "string.h"
#include "stdio.h"
#include <fstream.h>
#include <math.h>
#include <Dialogs.hpp>

//---------------------------------------------------------------------------
#pragma package(smart_init)
#pragma resource "*.dfm"
TForm1 *Form1;

char mydrive='c';  // default drive for installation
int counter;  // number of installation tasks
float longitude, latitude, height; // location paramter
char folder[120] = "CALLISTO-00"; // main folder, focus code will be added later
unsigned int icode=00; 

//---------------------------------------------------------------------------
__fastcall TForm1::TForm1(TComponent* Owner)
    : TForm(Owner)
{
   Memo1->Clear();
   Memo1->Lines->Add("Callisto-xx Installation script:");
   DriveComboBox1->Drive = mydrive;
}
//---------------------------------------------------------------------------
void __fastcall TForm1::DriveComboBox1Click(TObject *Sender)
{
   mydrive = DriveComboBox1->Drive;
}
//---------------------------------------------------------------------------
void __fastcall TForm1::Execute(char *cmd)
{
   WinExec(cmd,SW_HIDE);
   Form1->Memo1->Lines->Add(cmd);
   counter++;
   Sleep(50);
   ProgressBar1->Position=counter;
}
//---------------------------------------------------------------------------
void __fastcall TForm1::GenerateCallistoConfiguration(void)
{
    Word PYear, PMonth, PDay; //Present Day
    Word hour,  min,  sec,  msec;
    TDateTime dtPresent = Now();
    DecodeDate(dtPresent, PYear, PMonth, PDay);
    DecodeTime(dtPresent,hour, min, sec, msec);
    char st[180];

    sprintf(st,"%c:\\%s\\Application\\callisto.cfg",mydrive,folder);
    FILE *logf = fopen(st,"w");
    fprintf(logf,"/* Callisto configuration file generated by CallistoInstaller.exe */\n");
    fprintf(logf,"/* Automatically generated at %04i-%02i-%02i, %02i:%02i:%02i                */\n",PYear,PMonth,PDay,hour,min,sec);
    fprintf(logf,"/* Author: Christian Monstein, 2017-07-28, Version 1.1            */\n");
    fprintf(logf,"/*                                                                */\n");
    fprintf(logf,"[rxcomport]=%s   // Serial communication port COM1...COM18\n",Edit1->Text.c_str());
    fprintf(logf,"[observatory]=12   // Instrument CALLISTO=12, please don't change\n");
    fprintf(logf,"[instrument]=%s   // Filename for FIT-file -> instrument code in the data archive\n",Edit2->Text.c_str());
    fprintf(logf,"[titlecomment]=%s   // title of the application and keyword in OVS-files\n",Edit3->Text.c_str());
    fprintf(logf,"[origin]=%s   // place of the instrument (town, village or name)\n",Edit4->Text.c_str());

    latitude = atof(Edit5->Text.c_str());
    if (latitude >= 0)
       sprintf(st,"N,%06.2f",fabs(latitude));
    else
       sprintf(st,"S,%06.2f",fabs(latitude));
    fprintf(logf,"[latitude]=%s    // Instrument latitude []\n",st);

    longitude = atof(Edit6->Text.c_str());
    if (longitude >= 0)
       sprintf(st,"W,%06.2f",fabs(longitude));
    else
       sprintf(st,"E,%06.2f",fabs(longitude));
    fprintf(logf,"[longitude]=%s    // Instrument longitude []\n",st);

    height = atof(Edit7->Text.c_str());
    fprintf(logf,"[height]=%06.1f   // antenna altitude [m] asl\n",height);

    fprintf(logf,"[clocksource]=1   // 1=internal clock, 2=external 1MHz 5V TTL\n");
    fprintf(logf,"[filetime]=900   // observation time for one FIT-file = 15minutes\n");
    fprintf(logf,"[frqfile]=frq00001.cfg   // default frequency file/program\n");
    fprintf(logf,"[focuscode]=%s   // focus-code = number of instrument per location\n",Edit8->Text.c_str());
    fprintf(logf,"[mmode]=3   // recording mode: 2=calibrated data, 3=raw data\n");
    fprintf(logf,"[fitsenable]=1   // 0=no FIT-files, 1=write FIT-files to disc\n");

    fprintf(logf,"[datapath]=%c:\\%s\\FITfiles\\   // default data path\n",mydrive,folder);
    fprintf(logf,"[logpath]=%c:\\%s\\LogFiles\\   // default logfile path\n",mydrive,folder);
    fprintf(logf,"[lcpath]=%c:\\%s\\LightCurves\\   // default light curve path (LC*)\n",mydrive,folder);
    fprintf(logf,"[ovspath]=%c:\\%s\\OVSfiles\\   // default spectral overview path (OVS*)\n",mydrive,folder);

    fprintf(logf,"[chargepump]=1   // 0=pump off, 1=pump on\n");
    fprintf(logf,"[agclevel]=%s   // PWM level for tuner gain controil 50...255, default 120\n",Edit9->Text.c_str());
    fprintf(logf,"[detector_sens]=25.4   // sensitivity of log. detector in mV/dB, default 25.4\n");
    fprintf(logf,"[db_scale]=5   // dB per divison in XY_plot (1...10)\n");
    fprintf(logf,"[autostart]=0   // 0=no autostart, 1=autostart after power fail\n");
    fprintf(logf,"[priority]=1   // 0=NORMAL, 1=ABOVE, 2=HIGH, 3=REALTIME PRIORITY\n");
    fflush(logf);
    fclose (logf);
}
//---------------------------------------------------------------------------
void __fastcall TForm1::GenerateSchedulerConfiguration(void)
{
    Word PYear, PMonth, PDay; //Present Day
    Word hour,  min,  sec,  msec;
    TDateTime dtPresent = Now();
    DecodeDate(dtPresent, PYear, PMonth, PDay);
    DecodeTime(dtPresent,hour, min, sec, msec);
    char st[180];

    sprintf(st,"%c:\\%s\\AutoScheduler\\autosched.cfg",mydrive,folder);
    FILE *logf = fopen(st,"w");
    fprintf(logf,"/* Scheduler configuration file generated by CallistoInstaller.exe */\n");
    fprintf(logf,"/* Automatically generated at %04i-%02i-%02i, %02i:%02i:%02i                */\n",PYear,PMonth,PDay,hour,min,sec);
    fprintf(logf,"/* Author: Christian Monstein, 2017-07-27, Version 1.1            */\n");
    fprintf(logf,"/*                                                                */\n");
    fprintf(logf,"[longitude]=%6.2f    // Instrument longitude []\n",longitude);
    fprintf(logf,"[latitude]=%6.2f    // Instrument longitude []\n",latitude);
    fprintf(logf,"[height]=%6.1f    // Instrument altitude []\n",height);
    fprintf(logf,"[horizon]=%s    // elevation of horizon []\n",Edit10->Text.c_str());
    fprintf(logf,"[focuscode]=%s   // focus-code = number of instrument per location\n",Edit8->Text.c_str());
    fprintf(logf,"[measuremode]=3    // 0=stop, 2=calibrated, 3=raw data, 8=rfi-monitoring\n");
    sprintf(st,"%c:\\%s\\Application\\scheduler.cfg",mydrive,folder);
    fprintf(logf,"[cfgpath]=%s    // Callisto configuration path\n",st);
    fprintf(logf,"[monitoring]=1    // Radiomonitoring (rfi): 1=on, 2=off\n");
    fflush(logf);
    fclose (logf);
}
//---------------------------------------------------------------------------
void __fastcall TForm1::GenerateFrequencyGeneratorConfiguration(void)
{
    Word PYear, PMonth, PDay; //Present Day
    Word hour,  min,  sec,  msec;
    TDateTime dtPresent = Now();
    DecodeDate(dtPresent, PYear, PMonth, PDay);
    DecodeTime(dtPresent,hour, min, sec, msec);
    char st[180];

    sprintf(st,"%c:\\%s\\FrequencyGenerator\\params.cfg",mydrive,folder);
    FILE *logf = fopen(st,"w");
    fprintf(logf,"/* Frequency generator configuration file generated by CallistoInstaller.exe */\n");
    fprintf(logf,"/* Automatically generated at %04i-%02i-%02i, %02i:%02i:%02i                */\n",PYear,PMonth,PDay,hour,min,sec);
    fprintf(logf,"/* Author: Christian Monstein, 2017-07-07, Version 1.1            */\n");
    fprintf(logf,"/*                                                                */\n");

    fprintf(logf,"[ovspath]=%c:\\%s\\OVSfiles\\   // default spectral overview path (OVS*)\n",mydrive,folder);
    fprintf(logf,"[outputpath]=%c:\\%s\\Application\\\n",mydrive,folder); // default location for frequency file
    fprintf(logf,"/*                                                                */\n");
    fprintf(logf,"[nonlinchans]=8    // ignore lower 8 channels due to synthesizer delay\n");
    fprintf(logf,"[sweeplength]=200    // number of frequencies per sweep\n");
    fprintf(logf,"[startfreq]=45.0    // native lowest freqeuncy\n");
    fprintf(logf,"[stopfreq]=870.0    // native highest freqeuncy\n");
    fprintf(logf,"[locosc]=0.0    // no converter per default\n");
    fprintf(logf,"[filenumber]=99999    // number of the frequency file frq?????.cfg\n");

    fflush(logf);
    fclose (logf);
}
//---------------------------------------------------------------------------
void __fastcall TForm1::GenerateWebGeneratorConfiguration(void)
{
    Word PYear, PMonth, PDay; //Present Day
    Word hour,  min,  sec,  msec;
    TDateTime dtPresent = Now();
    DecodeDate(dtPresent, PYear, PMonth, PDay);
    DecodeTime(dtPresent,hour, min, sec, msec);
    char st[180];

    sprintf(st,"%c:\\%s\\WebGenerator\\wwwpar.cfg",mydrive,folder);
    FILE *logf = fopen(st,"w");
    fprintf(logf,"/* Web generator configuration file generated by CallistoInstaller.exe */\n");
    fprintf(logf,"/* Automatically generated at %04i-%02i-%02i, %02i:%02i:%02i                */\n",PYear,PMonth,PDay,hour,min,sec);
    fprintf(logf,"/* Author: Christian Monstein, 2017-09-15, Version 1.1            */\n");
    fprintf(logf,"/*                                                                */\n");

    fprintf(logf,"[configfile]=%c:\\%s\\Application\\callisto.cfg\n",mydrive,folder); // instrument configuration
    fprintf(logf,"[imagedir]=%c:\\%s\\Images\\\n",mydrive,folder); // target for plots
    fprintf(logf,"[timer]=5         // seconds for a re-plot of the image\n");
    fprintf(logf,"[dayoffset]=0     // DateOfFile = Today-dayoffset \n");
    fprintf(logf,"[yscale]=-5,35,8  // intensity-range (min, max, NrTicks) \n");
    fprintf(logf,"[width]=800       // width of the plot expressed in pixels \n");
    fprintf(logf,"[height]=496      // height of the plot expressed in pixels (nornal golden cut=h=0.62*w \n");
    fprintf(logf,"[adcdivider]=4    // data-format light curve only 8bit or 10bit? 8bit->1, 10bit->4\n");

    fflush(logf);
    fclose (logf);
}
//---------------------------------------------------------------------------
void __fastcall TForm1::GenerateLCplotterConfiguration(void)
{
}
//---------------------------------------------------------------------------
void __fastcall TForm1::GenerateLCPYplotterConfiguration(void)
{
}
//---------------------------------------------------------------------------
void __fastcall TForm1::GeneratePerlScript(void)
{
    Word PYear, PMonth, PDay; //Present Day
    Word hour,  min,  sec,  msec;
    TDateTime dtPresent = Now();
    DecodeDate(dtPresent, PYear, PMonth, PDay);
    DecodeTime(dtPresent,hour, min, sec, msec);
    
    char st[180];
    char pw[80];
    sprintf(st,"%c:\\%s\\PerlScripts\\ftp-gz.pl",mydrive,folder);
    FILE *logf = fopen(st,"wb");
    Sleep(200); // give some time to settle files on disc (????)

    char buff[180];
    FILE *infile;
    sprintf(st,"%c:\\%s\\PerlScripts\\ftp-gz.pl.src",mydrive,folder);
    infile = fopen(st,"r+");   // read PERL source file and add dynamic parameters
    while(!feof(infile))
    {
       fgets(buff,sizeof(buff),infile);  // read source line

       if (strstr(buff,"my $SourcePath "))
       {
          fprintf(logf,"my $SourcePath = '%c:/%s/FITfiles';%c%c",mydrive,folder,10,13);
       }
       else if (strstr(buff,"my $DestinationPath "))
       {
          fprintf(logf,"my $DestinationPath = '%c:/%s/FITbackup';%c%c",mydrive,folder,10,13);
       }
       else if (strstr(buff,"my $today = "))
       {
          fprintf(logf,"my $today = sprintf('%%04i%%02i%%02i', $tnow[5]+1900, $tnow[4]+1, $tnow[3]);%c%c",10,13);
       }
       else if (strstr(buff,"$ftp->login"))
       {
          sprintf(pw,Edit11->Text.c_str());
          fprintf(logf,"     $ftp->login(%csolarradio%c,%c%s%c) or die 'Cannot login ', $ftp->message;%c%c",34,34,34,pw,34,10,13);
          fprintf(logf,"\n\n");
       }
       else if (strstr(buff,"if ($filename ="))
       {
          fprintf(logf,"     if ($filename =~ /^%s_(\\d\\d\\d\\d)(\\d\\d)(\\d\\d)_.*\\.fit?$/)\n",Edit2->Text.c_str());
          fprintf(logf,"\n\n");
       }
       else
         fprintf(logf,buff);
         fprintf(logf,"\n");
    }
    fclose(infile);

    fflush(logf);
    fclose (logf);

    // perl script generated, delete the template
    sprintf(st,"cmd.exe /c del %c:\\%s\\PerlScripts\\ftpupload.pl.src",mydrive,folder);
    Execute(st);
}
//---------------------------------------------------------------------------
void __fastcall TForm1::Button1Click(TObject *Sender) // Install
{
   char cmd[240];
   counter = 0;
   if (CheckBox1->Checked)
      ProgressBar1->Max=18+8*3;   // 48
   else
      ProgressBar1->Max=18;

   icode = atoi(Edit8->Text.c_str());  // instrument code 00...63
   sprintf(folder,"CALLISTO-%02u",icode );
   
   sprintf(cmd,"cmd.exe /c md %c:\\%s\\Application",mydrive,folder);          Execute(cmd);
   sprintf(cmd,"cmd.exe /c md %c:\\%s\\FrequencyGenerator",mydrive,folder);   Execute(cmd);
   sprintf(cmd,"cmd.exe /c md %c:\\%s\\AutoScheduler",mydrive,folder);        Execute(cmd);
   sprintf(cmd,"cmd.exe /c md %c:\\%s\\WebGenerator",mydrive,folder);         Execute(cmd);
   sprintf(cmd,"cmd.exe /c md %c:\\%s\\PerlScripts",mydrive,folder);          Execute(cmd);

   sprintf(cmd,"cmd.exe /c md %c:\\%s\\FITfiles",mydrive,folder);             Execute(cmd);
   sprintf(cmd,"cmd.exe /c md %c:\\%s\\FITbackup",mydrive,folder);            Execute(cmd);
   sprintf(cmd,"cmd.exe /c md %c:\\%s\\LogFiles",mydrive,folder);             Execute(cmd);
   sprintf(cmd,"cmd.exe /c md %c:\\%s\\OVSfiles",mydrive,folder);             Execute(cmd);
   sprintf(cmd,"cmd.exe /c md %c:\\%s\\OVSbackup",mydrive,folder);            Execute(cmd);
   sprintf(cmd,"cmd.exe /c md %c:\\%s\\LightCurves",mydrive,folder);          Execute(cmd);
   sprintf(cmd,"cmd.exe /c md %c:\\%s\\Images",mydrive,folder);               Execute(cmd);
   sprintf(cmd,"cmd.exe /c md %c:\\%s\\Tools",mydrive,folder);                Execute(cmd);

   sprintf(cmd,"cmd.exe /c copy Application\\*.* %c:\\%s\\Application",mydrive,folder);                    Execute(cmd);
   sprintf(cmd,"cmd.exe /c copy FrequencyGenerator\\*.* %c:\\%s\\FrequencyGenerator",mydrive,folder);      Execute(cmd);
   sprintf(cmd,"cmd.exe /c copy FrequencyGenerator\\OVS*.prn %c:\\%s\\OVSfiles",mydrive,folder);           Execute(cmd);
   sprintf(cmd,"cmd.exe /c copy AutoScheduler\\*.* %c:\\%s\\AutoScheduler",mydrive,folder);                Execute(cmd);
   sprintf(cmd,"cmd.exe /c copy WebGenerator\\*.* %c:\\%s\\WebGenerator",mydrive,folder);                  Execute(cmd);
   sprintf(cmd,"cmd.exe /c copy PerlScripts\\*.* %c:\\%s\\PerlScripts",mydrive,folder);                    Execute(cmd);
   sprintf(cmd,"cmd.exe /c copy Tools\\*.* %c:\\%s\\Tools",mydrive,folder);                                Execute(cmd);
   sprintf(cmd,"cmd.exe /c copy Tools\\*.htm %c:\\%s\\Images",mydrive,folder);                             Execute(cmd);

   // xx steps
   //--------------------------------------------------------------------------------------------------------------------------------
   Sleep(50);
   GenerateCallistoConfiguration();
   counter++;
   ProgressBar1->Position=counter;
   sprintf(cmd,"Generate \\%s\\Application\\callisto.cfg",folder);
   Form1->Memo1->Lines->Add(cmd);

   GenerateSchedulerConfiguration();
   counter++;
   ProgressBar1->Position=counter;
   sprintf(cmd,"Generate \\%s\\AutoScheduler\\autosched.cfg",folder);
   Form1->Memo1->Lines->Add(cmd);

   GenerateFrequencyGeneratorConfiguration();
   counter++;
   ProgressBar1->Position=counter;
   sprintf(cmd,"Generate \\%s\\FrequencyGenerator\\params.cfg",folder);
   Form1->Memo1->Lines->Add(cmd);

   GenerateWebGeneratorConfiguration();
   counter++;
   ProgressBar1->Position=counter;
   sprintf(cmd,"Generate \\%s\\WebGenerator\\wwwpar.cfg",folder);
   Form1->Memo1->Lines->Add(cmd);

   GeneratePerlScript();
   counter++;
   ProgressBar1->Position=counter;
   sprintf(cmd,"Generate \\%s\\PerlScripts\\ftpupload.pl",folder);
   Form1->Memo1->Lines->Add(cmd);
   Sleep(50);

   // Generation Links
   //
   Sleep(100);
   char app[80];      //   -q:"c:\CALLISTO-xx\Application\callisto.exe"       -z:"%userprofile%\Desktop\CALLSTO.lnk"
   if (CheckBox1->Checked)
   {
     sprintf(cmd,"Generate links on the desktop.");
     Form1->Memo1->Lines->Add(cmd);
     for (int trial=0; trial<3; trial++)
     {
       sprintf(cmd,"Trial: %i",trial+1);
       Form1->Memo1->Lines->Add(cmd);

       sprintf(app,"CALLISTO-%02u",icode);
       sprintf(cmd,"cmd.exe /c %c:\\%s\\Tools\\MachLink.exe -q:%c%c:\\%s\\Application\\callisto.exe%c -w:%c%c:\\%s\\Application%c -z:%c%%userprofile%%\\Desktop\\%s.lnk%c",
         mydrive,folder,34,mydrive,folder,34,34,mydrive,folder,34,34,app,34);  Execute(cmd);
       Sleep(100);

       sprintf(app,"SCHEDULER-%02u",icode);
       sprintf(cmd,"cmd.exe /c %c:\\%s\\Tools\\MachLink.exe -q:%c%c:\\%s\\AutoScheduler\\SchedulerGeni.exe%c -w:%c%c:\\%s\\AutoScheduler%c -z:%c%%userprofile%%\\Desktop\\%s.lnk%c",
         mydrive,folder,34,mydrive,folder,34,34,mydrive,folder,34,34,app,34);  Execute(cmd);
       Sleep(100);

       sprintf(app,"FGENI-%02u",icode);
       sprintf(cmd,"cmd.exe /c %c:\\%s\\Tools\\MachLink.exe -q:%c%c:\\%s\\FrequencyGenerator\\GenFrqPrg.exe%c -w:%c%c:\\%s\\FrequencyGenerator%c -z:%c%%userprofile%%\\Desktop\\%s.lnk%c",
         mydrive,folder,34,mydrive,folder,34,34,mydrive,folder,34,34,app,34);  Execute(cmd);
       Sleep(100);

       sprintf(app,"WWWGENI-%02u",icode);
       sprintf(cmd,"cmd.exe /c %c:\\%s\\Tools\\MachLink.exe -q:%c%c:\\%s\\WebGenerator\\wwwgeni.exe%c -w:%c%c:\\%s\\WebGenerator%c -z:%c%%userprofile%%\\Desktop\\%s.lnk%c",
         mydrive,folder,34,mydrive,folder,34,34,mydrive,folder,34,34,app,34);  Execute(cmd);
       Sleep(100);

       sprintf(app,"JAVAVIEWER-%02u",icode);
       sprintf(cmd,"cmd.exe /c %c:\\%s\\Tools\\MachLink.exe -q:%c%c:\\%s\\Tools\\jv_20070109.jar%c -w:%c%c:\\%s\\Tools%c -z:%c%%userprofile%%\\Desktop\\%s.lnk%c",
         mydrive,folder,34,mydrive,folder,34,34,mydrive,folder,34,34,app,34);  Execute(cmd);
       Sleep(100);
     } // end for
    } // end if
    
    sprintf(cmd,"--------------------------------------------------------------");
    Form1->Memo1->Lines->Add(cmd);
    sprintf(cmd,"End of installation and preliminary configuration.");
    Form1->Memo1->Lines->Add(cmd);
    sprintf(cmd,"Some parameters probably need to be edited manually, depending on local situation regarding rfi, frequency range etc.");
    Form1->Memo1->Lines->Add(cmd);
    sprintf(cmd,"Now you may at least execute CALLISTO-xx, SCHEDULER-xx, WWWGENI-xx. Other applications on demand.");
    Form1->Memo1->Lines->Add(cmd);
    sprintf(cmd,"Here xx denotes to your instrument 01...24 which the maximum number of Callisto on one PC.");
    Form1->Memo1->Lines->Add(cmd);
    sprintf(cmd,"--------------------------------------------------------------");
    Form1->Memo1->Lines->Add(cmd);

    int nnn=counter;
   // 7 steps
   // in total 50 steps
}
//---------------------------------------------------------------------------
void __fastcall TForm1::Button2Click(TObject *Sender)
{
   Form1->Memo1->Lines->Add(" ");
   Form1->Memo1->Lines->Add("Help Callisto installer V2.1, 2019-05-26:");
   Form1->Memo1->Lines->Add("This tool should help you to quickly get all software installed which is required to operate a Callisto solar radio spectrometer.");
   Form1->Memo1->Lines->Add("And it should help in providing data to the international e-Callisto network within short time.");
   Form1->Memo1->Lines->Add(" ");
   Form1->Memo1->Lines->Add("Drive selection: Select one of your local or external discs.");
   Form1->Memo1->Lines->Add("If you don't have administrator rights, don't use drive c:, use another drive.");
   Form1->Memo1->Lines->Add("For communication port execute device manager (devmgmt.msc) or press button 'Check ports'.");
   Form1->Memo1->Lines->Add("Name for FIT file should contain your country. No special character, except -");
   Form1->Memo1->Lines->Add("We suggest to first check selected name with the principal investiator (PI) Chr. Monstein, email below");
   Form1->Memo1->Lines->Add("Title of your Callisto application. No special character except -");
   Form1->Memo1->Lines->Add("Name of the location of the instrument. No special character except -");
   Form1->Memo1->Lines->Add("Geographical latitude in decimal degree. (south=negative)");
   Form1->Memo1->Lines->Add("Geographical longitude in decimal degree. (east=negative)");
   Form1->Memo1->Lines->Add("Altitude of your antenna im meter above sea level.");
   Form1->Memo1->Lines->Add("Instrument or focus code describes your configuration. It's also applied to the SUB-D25 connector.");
   Form1->Memo1->Lines->Add("It is meant for numbering your instrument, start with 01 for your first instrument.");
   Form1->Memo1->Lines->Add("Gain control value to be optimized during commissioning with any text-editor.");
   Form1->Memo1->Lines->Add("Elevation of the Sun at sun-rise / sun-set in degree above local horizon. (Just a rough estimation)");
   Form1->Memo1->Lines->Add("Ask for password via email here: monstein@irsol.ch or here: cmonstein@swissonline.ch");
   Form1->Memo1->Lines->Add("CheckBox allows to create links to all applications on your desktop (default)");

   Form1->Memo1->Lines->Add("All configuration parameters can be edited anytime with a simple text-editor (e.g. NotePad)");
   Form1->Memo1->Lines->Add("Automatic scheduler needs to be configured inside the application ssfree.exe");
   Form1->Memo1->Lines->Add("We suggest every hour and every 15 minutes at 01, 16, 31 and 46, when FIT-files are ready");
   Form1->Memo1->Lines->Add("Before installation of PERL check your system if it is 32Bit or 64Bit");
   Form1->Memo1->Lines->Add("After installation of PERL you may most probably need to restart your PC");
   Form1->Memo1->Lines->Add("If the installation was successful, execute callisto.exe and SchedulerGeni.exe");
   Form1->Memo1->Lines->Add("Optionally execute LCPLOT and/or WWWGENI and/or LCPYplot");
   Form1->Memo1->Lines->Add("To generate a new frequency file, execute FGENI");
   Form1->Memo1->Lines->Add("In case you want to use Python version of LCplot, you first need to install Python 2.7 from here:");
   Form1->Memo1->Lines->Add("https://www.continuum.io/downloads then select PYTHON 2.7, WINDOWS 64-Bit Graphical Installer");
   Form1->Memo1->Lines->Add("You should get something like: Anaconda2-4.1.0-Windows-x86_64.exe");
   Form1->Memo1->Lines->Add("In case you want to use free visualisation tool jv_20070109.jar, install Java Run Time System first!");
   Form1->Memo1->Lines->Add("Help/Info shows this list.");
   Form1->Memo1->Lines->Add("Delete Callisto erases the whole Callisto installation INCLUDING OVS-, LOG-, FIT-archive and FIT-Backup!");
   Form1->Memo1->Lines->Add("");
   Form1->Memo1->Lines->Add("All information about hardware and software can be found here: http://www.e-callisto.org/");

}
//---------------------------------------------------------------------------
void __fastcall TForm1::Button6Click(TObject *Sender)
{
   char cmd[120];
   char app[80];
  
   icode = atoi(Edit8->Text.c_str());  // instrument code 00...63
   sprintf(folder,"CALLISTO-%02u",icode );

   sprintf(cmd,"Do you really want to erase %s folders?",folder);
   if (Application->MessageBox(cmd, "Warning", MB_YESNOCANCEL)==IDYES)
   {
     try
     {
       sprintf(cmd,"cmd.exe /c rd /s /q %c:\\%s",mydrive,folder);
       WinExec(cmd,SW_HIDE);
       Sleep(50);
       WinExec(cmd,SW_HIDE);
       Sleep(50);
       WinExec(cmd,SW_HIDE);
       sprintf(cmd,"Erasing folder %s, applications and data done...",folder);

       sprintf(app,"CALLISTO-%02u",icode);
       sprintf(cmd,"cmd.exe /c del %%userprofile%%\\Desktop\\%s.lnk",app); Execute(cmd);
       sprintf(app,"SCHEDULER-%02u",icode);
       sprintf(cmd,"cmd.exe /c del %%userprofile%%\\Desktop\\%s.lnk",app); Execute(cmd);
       sprintf(app,"FGENI-%02u",icode);
       sprintf(cmd,"cmd.exe /c del %%userprofile%%\\Desktop\\%s.lnk",app); Execute(cmd);
       sprintf(app,"WWWGENI-%02u",icode);
       sprintf(cmd,"cmd.exe /c del %%userprofile%%\\Desktop\\%s.lnk",app); Execute(cmd);
       sprintf(app,"JAVAVIEWER-%02u",icode);
       sprintf(cmd,"cmd.exe /c del %%userprofile%%\\Desktop\\%s.lnk",app); Execute(cmd);

       Form1->Memo1->Lines->Add("Desktop links erased...");
       counter=ProgressBar1->Max;
     }
     catch(...)
     {
        sprintf(cmd,"Error: Erasing %s did not succed.",folder);
        Form1->Memo1->Lines->Add(cmd);
     }
   }
}
//---------------------------------------------------------------------------
void __fastcall TForm1::Edit1MouseMove(TObject *Sender, TShiftState Shift,
      int X, int Y)
{
   ShowMessage(L"The edit box has received focus.");
}
//---------------------------------------------------------------------------
void __fastcall TForm1::Button7Click(TObject *Sender)
{
   WinExec("COMcheck.exe",SW_SHOW);
}
//---------------------------------------------------------------------------

